/*----------------------------------------------------------------------------\
|							Askia WebSimulator Objects						  |
|-----------------------------------------------------------------------------|
|                          Created by Askia Company							  |
|							(http://www.askia.com)							  |
|-----------------------------------------------------------------------------|
| Set a random response and try to go to the next screen					  |
|-----------------------------------------------------------------------------|
|							Copyright Askia  1994-2007						  |
|-----------------------------------------------------------------------------|
| Dependencies:																  |
|		- AskiaScript FrameWork (1.1.0)										  |
|-----------------------------------------------------------------------------|
| 2007-01-16 |V 1.0.0														  |
|			 |+	Set a random response										  |
|			 |+ Go to the next screen									      |
| 2007-01-17 |+ Manage the question date and the select box					  |
|-----------------------------------------------------------------------------|
| 2010-06-28 |V 1.0.1														  |
|			 |+	Add a timeout before post to avoid the massive load issue	  |
|-----------------------------------------------------------------------------|
| Created 2007-01-16 | All changes are in the log above. | Updated 2010-06-28 |
|-----------------------------------------------------------------------------|
|														All rights reserved	  |
| Plug-In - WebSimulator - API Version 1.0.1	Copyright Askia  1994-2010   |
\----------------------------------------------------------------------------*/

//Namespace of the plug-in
var WebSimulator={};

//This function will write the header in the page
WebSimulator.start=function(){	
		//Wait the entire loading of the page
		if (!document.body){
				setTimeout("WebSimulator.start();",75);
				return;
			}
		var btn=document.getElementsByName("Next");
		if (btn.length==0){
				setTimeout("WebSimulator.start();",75);
				return;		
			}
		
		//Search the questions and set a random response
		if (QuestionHandler.childNodes.length>0)WebSimulator.setRandomResponses();
		
		//Fix: 1.0.1 - Wait one second before to go next
		setTimeout("WebSimulator.goNext();",1000);
	}
	
//Specify a random response
WebSimulator.setRandomResponses=function(){
		for (var i=0;i<QuestionHandler.childNodes.length;i++){
				var q=QuestionHandler.childNodes[i];
				switch(q.type){
					case eQuestionType.chapter:
						//Do nothing
						break;
					case eQuestionType.numeric:
						this._setToNumericQuestion(q);
						break;
					case eQuestionType.multiple:
						this._setToMultipleQuestion(q);
						break;
					case eQuestionType.open:
						this._setToOpenQuestion(q);
						break;
					case eQuestionType.single:
						this._setToSingleQuestion(q);
						break;
					case eQuestionType.date:
						this._setToDateQuestion(q);
						break;				
					}
			}
	}
//Set a random response into date question
WebSimulator._setToDateQuestion=function(question){
		var min=(question.min)?question.min:getDateToString(new Date());
		var max=(question.max)?question.max:getDateToString(new Date());
		var useMin=this._getRandomValue(0,1);
		question.childNodes[0].htmlControl.value=(useMin)?min:max;
	}
//Set a random response into the open-ended question
WebSimulator._setToOpenQuestion=function(question){
		var value=question.caption;
		if (question.max){
				if (value.length>question.max){
						value=value.substring(0,question.max);
					}
			}
		question.childNodes[0].htmlControl.value=value;
	}
//Set a random response to numeric question
WebSimulator._setToNumericQuestion=function(question){
		var min =(question.min)?question.min:0;
		var max =(question.max)?question.max:100;
		var value=this._getRandomValue(min,max);
		question.childNodes[0].htmlControl.value=value;
	}
//Set a random values to single question
WebSimulator._setToSingleQuestion=function(question){
		var max=(!question.isUseList)?(question.childNodes.length-1):(question.childNodes[0].htmlControl.options.length-1);
		if (!question.isUseList && question.isSemiOpen)max--;
		var rIndex=this._getRandomValue(0,max);
		if (!question.isUseList){
				for (var i=0;i<question.childNodes.length;i++){
						question.childNodes[i].htmlControl.checked=false;
					}
				question.childNodes[rIndex].htmlControl.checked=true;
				question.childNodes[rIndex].click();	
			}
		else {
				question.childNodes[0].value=rIndex;
				question.childNodes[0].select();
			}
		
		//Check the semi-open response
		this._checkSemiOpen(question);		
	}
//Set a random values to multiple question
WebSimulator._setToMultipleQuestion=function(question){
		//Search the min and max of allowed responses
		var min=(question.min)?question.min:0;
		var max=question.childNodes.length-1;
		if (question.isSemiOpen)max--;
		if (question.max)max=question.max;
		
		//Number of responses
		var numberOfResponses=this._getRandomValue(min,max);
		//Keep the exclusive answer into the random selection
		var isKeepExclu=this._getRandomValue(0,1);
		//Values already affected (to don't have a duplicate random value)
		var _arrSelValues={};
		//Select a random values 
		for (var i=0;i<numberOfResponses;i++){
				//Select a random response without duplicate values
				var rIndex=this._getRandomValue(0,question.childNodes.length-1);
				while (_arrSelValues[rIndex]){
						rIndex=this._getRandomValue(0,question.childNodes.length-1);
					}
					
				//Simulate the selection of response
				question.childNodes[rIndex].htmlControl.checked=true;
				question.childNodes[rIndex].click();
				
				//Set the selected value (don't select it again)
				_arrSelValues[rIndex]=true;
				
				//If we keep the exclusive response 
				//and the value selected is exclusive
				//then break the loop
				if (isKeepExclu && question.childNodes[rIndex].isExclusive)break;
			}
			
		//Check the semi-open response
		this._checkSemiOpen(question);
	}
//Manage the semi-open response
WebSimulator._checkSemiOpen=function(question){
		//Management of semi-open
		if(!question.isSemiOpen || !question._semiOpenResponse || (!question.all[eResponseId.semiOpen] && !question.isUseList))return true;
		var isSemiSelected=(!question.isUseList)?question.all[eResponseId.semiOpen].htmlControl.checked:(question.childNodes[0].htmlControl.value==eResponseId.semiOpen);
		if (!isSemiSelected)return true;
		//Set the open value
		var value=question.caption;		
		if (question.maxSemiOpen){
				if (value.length>question.max){
						value=value.substring(0,question.maxSemiOpen);
					}
			}		
		question._semiOpenResponse.htmlControl.value=value;
	}
//Return a random value between min & max
WebSimulator._getRandomValue=function(min,max){
		var value=Math.round(Math.random()* max) + min;
		if (value>max)return max;
		return value;
	}
//Go to next screen
WebSimulator.goNext=function(){
		var btn=document.getElementsByName("Next");
		if (btn.length>0)btn[0].click();
	}
	
//Start the process
WebSimulator.start();